﻿using System;
using System.Diagnostics;
using System.Text;
using Windows.ApplicationModel.AppService;
using Windows.UI.Core;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Navigation;

namespace UiApp
{
	public sealed partial class MainPage : Page
	{
		public MainPage()
		{
			this.InitializeComponent();
		}

		private static readonly string ServiceName = "BgApp";
		private AppServiceConnection service = null;

		protected override async void OnNavigatedTo(NavigationEventArgs e)
		{
			base.OnNavigatedTo(e);

			var listing = await AppServiceCatalog.FindAppServiceProvidersAsync(ServiceName);
			if (listing.Count != 1) return;

			service = new AppServiceConnection();
			service.AppServiceName = ServiceName;
			service.PackageFamilyName = listing[0].PackageFamilyName;

			var res = await service.OpenAsync();
			if (res != AppServiceConnectionStatus.Success) {
				lblMsg.Text = "Could not connect to the App Service: " + res.ToString();
			} else {
				service.RequestReceived += OnServiceRequestReceived;
				lblMsg.Text = "Ready";
			}
		}

		private async void OnServiceRequestReceived(AppServiceConnection sender, AppServiceRequestReceivedEventArgs args)
		{
			bool isButtonEnabled = true;
			await Dispatcher.RunAsync(CoreDispatcherPriority.Normal, () => {
				isButtonEnabled = btnReceive.IsEnabled;
			});
			if (isButtonEnabled == true) return;

			int[] infsignal = args.Request.Message["infrared"] as int[];
			if (infsignal != null) {
				StringBuilder sb = new StringBuilder();
				foreach (int n in infsignal) {
					sb.AppendFormat("{0},", n);
				}

				await Dispatcher.RunAsync(CoreDispatcherPriority.Normal, () => {
					txtSignal.Text = sb.ToString();
					btnReceive.IsEnabled = true;
				});
			}
		}

		private void OnClickReceive(object sender, RoutedEventArgs e)
		{
			btnReceive.IsEnabled = false;
		}

		private void OnClickDebugger(object sender, RoutedEventArgs e)
		{
			Debug.Write(txtSignal.Text);
		}
	}
}
